@@ -28,7 +28,7 @@ class Selenium(Scraper):
 
         options.add_argument('--no-sandbox')
         options.add_argument('--disable-dev-shm-usage')
-        options.add_argument('--start-maximized')
+        options.add_argument('start-maximized')
         self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
 
         # #region undetected_chromedriver
